## Make Slug
Make a slug value (a part of a URL) from a regular sentence.

### Installation

Type this command into your terminal:

```bash
pip install mkslug
```

### Usage

To use mkslug, type this command into your terminal with your sentence:

```bash
python -m mkslug 'Example regular sentence.'
```
